@@ -94,9 +94,11 @@ ChineseCalendar::ChineseCalendar(QWidget *parent)
     this->label_13->setText(chineseday);
     this->label_14->setFont(font);
     this->label_14->setText(chineseyear);
+    this->label_19->setFont(font);
 //    font.setPointSize(15);
 //    this->label_15->setFont(font);
-    font.setPointSize(10);
+    font.setPointSize(9);
+    font.setFamily("Serif");
     this->label_17->setFont(font);
     this->label_18->setFont(font);
 
@@ -131,8 +133,8 @@ ChineseCalendar::ChineseCalendar(QWidget *parent)
     this->label_18->setText(ji);
 
     QString cnote=mycalendat->ctcl_displaydata(day.year(),day.month(),day.day());
-    QString haveplan=QString("今日有行程安排");
-    QString noplan=QString("今日无行程安排");
+    QString haveplan=QString("写便签请双击日期");
+    QString noplan=QString("写便签请双击日期");
     int num=cnote.count();
     while( num > 0 && cnote.at(num-1).isSpace())
     {
@@ -496,6 +498,7 @@ void ChineseCalendar::savedata(QString data)
     mycalendat->ctcl_savenote(year,month,day,data);
     note->hide();
 
+    setCalendar();
 }
 
 
@@ -872,8 +875,8 @@ void ChineseCalendar::resetcalendardate(QString day)
     this->label_14->setText(selectyear);
 
     QString cnote=QString("");
-    QString haveplan=QString("今日有行程安排");
-    QString noplan=QString("今日无行程安排");
+    QString haveplan=QString("写便签请双击日期");
+    QString noplan=QString("写便签请双击日期");
     cnote=mycalendat->ctcl_displaydata(date.year(),date.month(),date.day());
     int num=cnote.count();
     while( num > 0 && cnote.at(num-1).isSpace())
@@ -976,6 +979,14 @@ void ChineseCalendar::setCalendar(bool flag)
         QString site = QString("%1-%2").arg(row).arg(weekDay+1);
         map->value(site)->setday(date.day());
         map->value(site)->setcday(mycday);
+
+        QString cnote = mycalendat->ctcl_displaydata(date.year(),date.month(),date.day());
+        int num=cnote.count();
+        if(cnote.isEmpty() || num == 0)
+            map->value(site)->setNoteCorner(false);
+        else
+            map->value(site)->setNoteCorner(true);
+
         if(weekDay == 6 || weekDay == 0)
             map->value(site)->setcolor();
          date = date.addDays(1);
