@@ -34,6 +34,7 @@ DateItem::DateItem(QWidget *parent) :
     font1.setPointSize(10);
     ui->label->setFont(font);
     ui->label_2->setFont(font1);
+    ui->noteCorner->hide();
 
     connect(ui->datemaskwidget, SIGNAL(clicked()), this, SLOT(click()));
     connect(ui->datemaskwidget, SIGNAL(clickday()), this, SLOT(clickday()));
@@ -103,9 +104,15 @@ void DateItem::enter()
 {
     if (!ui->label->text().isNull())
     {
-        this->ui->bg->setStyleSheet(this->hoverItemStyle);
-        ui->label->setStyleSheet(this->hoverDayStyle);
-        ui->label_2->setStyleSheet(this->hoverCDayStyle);
+        if(this->isFocus){
+            this->ui->bg->setStyleSheet(this->clickiItemStyle);
+            ui->label->setStyleSheet(this->clickDayStyle);
+            ui->label_2->setStyleSheet(this->clickCDayStyle);
+        }else{
+            this->ui->bg->setStyleSheet(this->hoverItemStyle);
+            ui->label->setStyleSheet(this->hoverDayStyle);
+            ui->label_2->setStyleSheet(this->hoverCDayStyle);
+        }
     }
 }
 
@@ -120,7 +127,7 @@ void DateItem::leave()
         ui->label->setStyleSheet(this->oriDayStyle);
         ui->label_2->setStyleSheet(this->oriCDayStyle);
     }
-    emit resetColor();
+//    emit resetColor();
 }
 
 
@@ -133,7 +140,7 @@ void DateItem::click()
         ui->label->setStyleSheet(this->clickDayStyle);
         ui->label_2->setStyleSheet(this->clickCDayStyle);
         this->isFocus = true;
-        emit resetColor();
+//        emit resetColor();
     }
 }
 
@@ -156,6 +163,17 @@ void DateItem::setcday(QString cday)
     ui->label_2->setText(cday);
 }
 
+void DateItem::setNoteCorner(bool flag)
+{
+    if(flag)
+    {
+        ui->noteCorner->show();
+    }else
+    {
+        ui->noteCorner->hide();
+    }
+}
+
 QString DateItem::day()
 {
     return ui->label->text();
@@ -170,6 +188,7 @@ void DateItem::clear()
 {
     ui->label->clear();
     ui->label_2->clear();
+    ui->noteCorner->hide();
     this->clearstyle();
 }
 
