@@ -39,9 +39,12 @@ int main(int argc, char *argv[])
     QTextCodec::setCodecForCStrings(QTextCodec::codecForName("UTF-8"));
 //    QApplication app(argc, argv);
     QTranslator translator;
+    QTranslator translatorMenu;
 
     translator.load(":/translate/i18_zh_CN.qm");
+    translatorMenu.load(":/translate/qt_zh_CN.qm");
     app.installTranslator(&translator);
+    app.installTranslator(&translatorMenu);
 
 // load default skin
 //#ifdef DEBUG
